@@ -17,6 +17,25 @@ from typing import List, Dict, Any, Optional
 
 log=logging.getLogger(__name__)
 
+
+class ExecResult():
+    def __init__(self, exit_status_code, stdout="", stderr=""):
+        self.__exit_status_code = exit_status_code
+        self.__stdout = stdout
+        self.__stderr = stderr
+
+    @property
+    def exit_status_code(self):
+        return self.__exit_status_code
+
+    @property
+    def stdout(self):
+        return self.__stdout
+
+    @property
+    def stderr(self):
+        return self.__stderr
+
 def enter_and_leave_function(func: Callable) -> Callable:
     """
     函数调用日志装饰器：
@@ -39,10 +58,22 @@ def enter_and_leave_function(func: Callable) -> Callable:
 
         try:
             result = func(*args, **kwargs)
-            log.info(
-                f"[{func_def_file}: {func_def_line}]"
-                f" finish run function {func.__name__}(), return value is: {result} "
-            )
+            if isinstance(result, ExecResult):
+                if rs.exit_status_code == 0:
+                    log.info(
+                        f"[{func_def_file}: {func_def_line}]"
+                        f" finish run function {func.__name__}(), stdout is: {rs.stdout} "
+                    )
+                else:
+                    log.error(
+                        f"[{func_def_file}: {func_def_line}]"
+                        f" failed to run function {func.__name__}(), stderr is: {rs.stderr} "
+                    )
+            else:
+                log.info(
+                    f"[{func_def_file}: {func_def_line}]"
+                    f" finish run function {func.__name__}(), return value is: {result} "
+                )
             return result
 
         except Exception as e:
@@ -60,26 +91,6 @@ def enter_and_leave_function(func: Callable) -> Callable:
 
     return wrapper
 
-
-class ExecResult():
-    def __init__(self, exit_status_code, stdout="", stderr=""):
-        self.__exit_status_code = exit_status_code
-        self.__stdout = stdout
-        self.__stderr = stderr
-
-    @property
-    def exit_status_code(self):
-        return self.__exit_status_code
-
-    @property
-    def stdout(self):
-        return self.__stdout
-
-    @property
-    def stderr(self):
-        return self.__stderr
-
-
 class SSHClient(object):
     def __init__(self, ip="127.0.0.1", port=22, username="root", password="", connect_timeout=10):
         self.__ip = ip
